<?php
$postData = file_get_contents('php://input');
$data = json_decode($postData, true);

require_once __DIR__ . '/../../../init.php';
require_once __DIR__ . '/../../../includes/gatewayfunctions.php';
require_once __DIR__ . '/../../../includes/invoicefunctions.php';
require_once __DIR__ . '/../../../includes/functions.php';


$gatewayModuleName = basename(__FILE__, '.php');

require __DIR__ . '/../' . $gatewayModuleName . '/vendor/autoload.php';

$gatewayParams = getGatewayVariables($gatewayModuleName);

if (!$gatewayParams['type']) {
    http_response_code(403);
    die('Module Not Activated');
}

$apiSecretKey = $gatewayParams['MerchantKey'];
$hmacHeader = $_SERVER['HTTP_HMAC'];
$calculatedHmac = hash_hmac('sha512', $postData, $apiSecretKey);

if ($calculatedHmac === $hmacHeader) {
    $success = ($data['status'] === 'Paid' );
    $transactionStatus = $success ? 'Success' : 'Failure';
    $invoiceId = preg_replace('/^whmcs_id_/', '', $data['orderId'] ?? '');
    $transactionId = $data['trackId'] ;
    logTransaction($gatewayParams['name'], $data, $transactionStatus);
    $invoiceId = checkCbInvoiceID($invoiceId, $gatewayParams['name']);
    if ($success && $transactionId) {
        checkCbTransID($transactionId);
        $paymentAmount = $data['amount'];
        addInvoicePayment(
            $invoiceId,
            $transactionId,
            $paymentAmount,
            '0.00',
            $gatewayModuleName
        );
    }

}
else{
    http_response_code(403);
    die('Hash Verification Failure');
}

die('OK');
