<?php

if (!defined('WHMCS')) {
    die('This file cannot be accessed directly');
}

require 'oxapaygateway/vendor/autoload.php';

function oxapaygateway_MetaData(): array
{
    return [
        'DisplayName' => 'OxaPay',
        'APIVersion' => '1.0',
        'DisableLocalCreditCardInput' => true,
        'failedEmail' => 'Credit Card Payment Failed',
        'successEmail' => 'Invoice Payment Confirmation',
        'pendingEmail' => 'Credit Card Payment Pending',
        'TokenisedStorage' => false,
    ];
}

function oxapaygateway_config(): array
{
    $hours = ['30' => '30 Min'];
    for ($i = 30; $i <= 120; $i += 30)
        $hours[$i] = $i . ' Min';

    return [
        'FriendlyName' => [
            'Type' => 'System',
            'Value' => 'OxaPay',
        ],
        'MerchantKey' => [
            'FriendlyName' => 'Merchant API Key',
            'Type' => 'text',
            'Description' => 'Enter your Merchant API Key here',
        ],
        'lifetime' => [
            'FriendlyName' => 'Invoice Lifetime',
            'Type' => 'dropdown',
            'Options' => $hours,
            'Description' => 'Set the expiration time for the payment link in minutes (15-2880)',
        ],
        'payNowLabel' => [
            'FriendlyName' => 'Pay Now Button Text',
            'Type' => 'text',
            'Default' => 'Pay with OxaPay',
            'Description' => 'Enter the text for the payment button',
        ],
    ];
}

function oxapaygateway_link(array $params): string
{
    $merchantKey = $params['MerchantKey'];
    $langPayNow = $params['payNowLabel'] ?? 'Pay with OxaPay';

    $invoiceId = $params['invoiceid'];
    $amount = $params['amount'];
    $currencyCode = $params['currency'];

    $lifetime = $params['lifetime'] ?? 60; 

    $systemUrl = $params['systemurl'];
    $returnUrl = $params['returnurl'];
    $moduleName = $params['paymentmethod'];
    $url = 'https://api.oxapay.com/merchants/request';
    $data = []; 
    $data['merchant'] = $merchantKey;
    $data['amount'] = (string)$amount;
    $data['currency'] = $currencyCode;
    $data['orderId'] = 'whmcs_id_' . $invoiceId;
    $data['returnUrl'] = $returnUrl;
    $data['callbackUrl'] = $systemUrl . '/modules/gateways/callback/' . $moduleName . '.php';
    $data['lifeTime'] = $lifetime;

    $options = array(
        'http' => array(
            'header' => 'Content-Type: application/json',
            'method'  => 'POST',
            'content' => json_encode($data),
        ),
    );
    
    $context  = stream_context_create($options);
    $response = file_get_contents($url, false, $context);
    $result = json_decode($response);
    


    $htmlOutput = '<form action="' . htmlspecialchars($result->payLink, ENT_QUOTES) . '">';
    $htmlOutput .= '<input type="submit" value="' . htmlspecialchars($langPayNow, ENT_QUOTES) . '"/>';
    $htmlOutput .= '</form>';
    $htmlOutput .= '<!--' . print_r($params, true) . "-->";

    return $htmlOutput;
}
